# -*- coding: utf-8; -*-
################################################################################
#
#  WuttaPOS -- Pythonic Point of Sale System
#  Copyright © 2023 Lance Edgar
#
#  This file is part of WuttaPOS.
#
#  WuttaPOS is free software: you can redistribute it and/or modify it under the
#  terms of the GNU General Public License as published by the Free Software
#  Foundation, either version 3 of the License, or (at your option) any later
#  version.
#
#  WuttaPOS is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
#  details.
#
#  You should have received a copy of the GNU General Public License along with
#  WuttaPOS.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################
"""
WuttaPOS - txn item control
"""

import flet as ft

from .base import WuttaControl


class WuttaTxnItem(WuttaControl):
    """
    Control for displaying a transaction line item within main POS
    items list.
    """
    font_size = 24

    def __init__(self, config, row, *args, **kwargs):
        super().__init__(config, *args, **kwargs)
        self.row = row

    def build(self):

        kw = {}
        if self.row.void:
            kw['color'] = 'red'
            kw['decoration'] = ft.TextDecoration.LINE_THROUGH

        self.major_style = ft.TextStyle(size=self.font_size,
                                        weight=ft.FontWeight.BOLD,
                                        **kw)

        self.minor_style = ft.TextStyle(size=int(self.font_size * 0.8),
                                        italic=True,
                                        **kw)

        quantity = self.app.render_quantity(self.row.quantity)
        pretty_price = self.app.render_currency(self.row.txn_price)

        return ft.Row(
            [
                ft.Row([

                    ft.Text(
                        spans=[
                            ft.TextSpan(f"{self.row.description}",
                                        style=self.major_style),
                            ft.TextSpan(f"× {quantity} @ {pretty_price}",
                                        style=self.minor_style),
                        ],
                    ),
                ]),
                ft.Text(
                    spans=[
                        ft.TextSpan(self.app.render_currency(self.row.sales_total),
                                    style=self.major_style),
                    ],
                ),

            ],
            alignment=ft.MainAxisAlignment.SPACE_BETWEEN,
        )

    def mark_void(self):

        self.major_style.color = 'red'
        self.major_style.decoration = ft.TextDecoration.LINE_THROUGH

        self.minor_style.color = 'red'
        self.minor_style.decoration = ft.TextDecoration.LINE_THROUGH

        self.update()
